      PROGRAM EVALNG  
C
C     USES MONTE CARLO SIMULATION TO ESTIMATE THE C.D.F. AND THE 
C     EXPECTED NUMBER OF TREATMENTS SELECTED BY PROCEDURE N_G WHEN THE
C     MEANS ARE IN THE SLIPPAGE (SC) AND EQUALLY-SPACED (ES) CONFIGS. 
C
C  INPUT: PROGRAM INTERACTIVELY PROMPTS FOR
C       T          = NUMBER OF TREATMENTS  (T .LEQ. 50-RESET BY MAXT)
C       DELTA      = DIFFERENCE BETWEEN LARGEST AND REMAINING MEANS
C       P-STAR     = MINIMUM PROBABILITY OF CORRECT SELECTION 
C       N          = NUMBER OF OBSERVATIONS PER TREATMENT
C       SIGMA      = STANDARD DEVIATION OF THE MEASURE ERROR
C       REPS       = NUMBER OF INDEPENDENT SIMULATION REPLICATIONS
C       ISEED      = INTEGER RANDOM NUMBER SEED
C
C  OUTPUT: EST'D P{S.GEQ.K | SC}, P{S.GEQ.K | ES} (1 .LEQ. K .LEQ. T),
C          E{S|SC} AND E{S|ES}, WHERE
C                   SC = (0,...,0,DELTA)
C          AND      ES = (0,DELTA,...,(T-1)*DELTA)
C
      INTEGER MAXT
C     MAXT DEFINES THE MAXIMUM NUMBER OF TREATMENTS
      PARAMETER (MAXT=50)
      DOUBLE PRECISION MULTZ
      DOUBLE PRECISION DELTA,PSTAR,SIGMA
      DOUBLE PRECISION CON1,CON2,H,CDFSC(MAXT),CDFES(MAXT),
     *      YBARSC(MAXT),YBARES(MAXT),YBMXSC,YBMXES,ESSC,ESES
      INTEGER ISEED,N,REPS,T
      INTEGER I,I400,SIZEES,SIZESC,TM1
      CHARACTER CHOICE2
      EXTERNAL MULTZ,UNIF,RNORML
C
C     READ PARAMETERS TO BE STUDIED
C
      WRITE(6,*) 'ENTER T AND SIGMA'
      READ(5,*) T,SIGMA
      WRITE(6,*)'ENTER NUMBER OF SIMULATION REPS AND INTEGER SEED'
      READ(5,*)REPS,ISEED
      WRITE(6,*) ' '
40    WRITE(6,*) 'ENTER N, DELTA AND P-STAR'
      READ(5,*) N,DELTA,PSTAR
C
      TM1 = T-1
      H = MULTZ(PSTAR,TM1)
C
      CON1 = SIGMA/N**0.5
      CON2 = H*SIGMA*DSQRT(2.0D0/N)
C
      DO 50 I = 1,T
      CDFSC(I) = 0.0D0
50    CDFES(I) = 0.0D0
      ESSC = 0.0D0
      ESES = 0.0D0
C
C     MAIN LOOP...
C
      DO 400 I400 = 1,REPS
C
C     GENERATE T SAMPLE MEANS (ASSUME TREATMENT T IS BEST)
C
      DO 110 I = 1,T
      YBARSC(I) = CON1 * RNORML(ISEED)
110   YBARES(I) = YBARSC(I) + (I-1)*DELTA
      YBARSC(T) = YBARSC(T) + DELTA
C
C     FIND MAXIMUM YBAR'S FOR SC AND ES CONFIG'S
      YBMXSC = YBARSC(1)
      YBMXES = YBARES(1)
      DO 120 I = 2,T
      IF(YBARSC(I).GT.YBMXSC)YBMXSC = YBARSC(I)
120   IF(YBARES(I).GT.YBMXES)YBMXES = YBARES(I)
C
C     FIND SIZE OF SELECTED SUBSET
      SIZESC = 0
      SIZEES = 0
      DO 130 I = 1,T
      IF(YBARSC(I).GE.YBMXSC-CON2)SIZESC = SIZESC + 1
130   IF(YBARES(I).GE.YBMXES-CON2)SIZEES = SIZEES + 1
C
C     UPDATE ESTIMATED C.D.F.'S
C
      CDFSC(SIZESC) = CDFSC(SIZESC) + 1.0D0
      CDFES(SIZEES) = CDFES(SIZEES) + 1.0D0
400   CONTINUE
C 
C     GET P.M.F.'S AND EXPECTED SUBSET SIZES
C
      WRITE(6,*)' '
      DO 410 I = 1,T
      CDFSC(I) = CDFSC(I)/REPS
      CDFES(I) = CDFES(I)/REPS
      ESSC = ESSC + I*CDFSC(I)
410   ESES = ESES + I*CDFES(I)
C
C     GET COMPLEMENTS OF C.D.F.'S
C
      DO 420 I = 2,T
      CDFSC(T+1-I) = CDFSC(T+1-I) + CDFSC(T+2-I)
420   CDFES(T+1-I) = CDFES(T+1-I) + CDFES(T+2-I)
C
      WRITE(6,430)
430   FORMAT(1X,'  K  P{S.GEQ.K | SC}  P{S.GEQ.K | ES} ')
      DO 500 I = 1,T
      WRITE(6,440)I,CDFSC(I),CDFES(I)
440   FORMAT(1X,I3,4X,F8.4,9X,F8.4)
500   CONTINUE
      WRITE(6,510)ESSC,ESES
510   FORMAT(1X,' E{S|SC} = ',F8.4,'  E{S|ES} = ',F8.4)
C
      WRITE(6,*)' '
      WRITE(6,*) 'DO YOU WANT TO CONTINUE? PLEASE ANSWER Y/N'
      READ(5,600) CHOICE2
600   FORMAT(A1)  
      IF (CHOICE2 .EQ. 'Y' .OR. CHOICE2 .EQ. 'y') GOTO 40
      STOP
      END

