      DOUBLE PRECISION FUNCTION MULTZ(PSTAR,P)
C
C     CALCULATES Z^{1-PSTAR}_{P,1/2}, THE ONE-SIDED UPPER (1-PSTAR) 
C     EQUICOORDINATE POINT OF THE P-DIMENSIONAL MULTIVARIATE NORMAL 
C     DISTRIBUTION WITH COMMON CORRELATION 1/2 AND UNIT VARIANCES
C
C  INPUT:  P       = DIMENSION OF THE MULTIVARIATE NORMAL DISTRIBUTION
C          1-PSTAR = UPPER TAIL PROBABILITY
C
C  OUTPUT: Z^{1-PSTAR}_{P,1/2}
C
      INTEGER MAXT
C     MAXT DEFINES THE MAXIMUM NUMBER OF TREATMENTS
      PARAMETER (MAXT=50)
      DOUBLE PRECISION PCSNB
      DOUBLE PRECISION PSTAR
      DOUBLE PRECISION ANS,H,LOWERH,TMP,UPPERH,IP
      INTEGER P,T,NTMP(MAXT),I
      EXTERNAL PCSNB
C 
C     CHECK INPUT VALUES
      IP = 1.0D0/DFLOAT(MAX0(P,2))
      IF ((IP .LT. PSTAR) .AND. (PSTAR .LT. 1.0D0)) THEN 
              GOTO 100
      ELSE
              MULTZ = -1.0D0
              WRITE(*,*) ' P^* ENTRY ERROR!!'
              RETURN
      END IF
C
100   T = P + 1
      DO 110 I = 1,T
110   NTMP(I) = 1
C
C     DETERMINE UPPER AND LOWER VALUES AT WHICH TO START BISECTION
C
      H = 0.0D0
      LOWERH = 0.0D0
C
C     EVALUATE THE P{CS} AT A TRIAL DELTA-STAR
C
120   TMP = H*DSQRT(2.0D0)
      ANS = PCSNB(T,NTMP,TMP,1.0D0)
C
      IF(ANS .GT. PSTAR) GOTO 130
      H = H + 1.0D0
      GOTO 120
130   UPPERH = H
      H = (UPPERH + LOWERH)/2.0D0
C
C     PERFORM BINARY SEARCH WITH A MAXIMUM OF 50 ITERATIONS
      DO 140 I = 1,50
      TMP = H*DSQRT(2.0D0)
      ANS = PCSNB(T,NTMP,TMP,1.0D0)
      IF(DABS(ANS-PSTAR).LE.0.000001) GOTO 150
      IF(ANS.GT.PSTAR) GOTO 160
      LOWERH = H
      H = (LOWERH + UPPERH)/2.
      GOTO 140
160   UPPERH = H
      H = (LOWERH + UPPERH)/2.
140   CONTINUE
150   MULTZ = H
      RETURN
      END

