      PROGRAM USEGSA
C
C     INTERACTIVE CALCULATION OF N, H OR DELTA-STAR FOR THE
C     SINGLE-STAGE PROCEDURE N_{GSa} TO ACHIEVE THE PROBABILITY 
C     REQUIREMENT OF SECTION 3.4.3
C
C  INPUT (PROGRAM INTERACTIVELY PROMPTS FOR):
C       T          = NUMBER OF TREATMENTS  
C       Q          = SIZE OF THE SUBSET
C       SIGMA      = STANDARD DEVIATION OF THE MEASURE ERROR
C       P-STAR     = MINIMUM P{CS} OVER THE INDIFFERENCE-ZONE 
C  THEN PROMPTS FOR 1 OF 3 CHOICES FROM THE MENU
C
C           CHOICE          GIVEN               FIND
C             1             N, H             DELTA-STAR
C             2         DELTA-STAR, H            N
C             3         DELTA-STAR, N            H
C  WHERE 
C       DELTA-STAR = DIFFERENCE TO BE DETECTED 
C       N          = SMALLEST COMMON OF OBSERVATIONS PER TREATMENT TO 
C                    ATTAIN THE PROBABILITY REQUIREMENT (3.4.7)
C       H          = LENGTH OF THE YARDSTICK USED BY N_{GSa}
C                
C  OUTPUT: DELTA-STAR, N OR H
C
      DOUBLE PRECISION ZCDF,PCSNGS,FACTOR
      DOUBLE PRECISION PSTAR,DSTAR,SIGMA
      DOUBLE PRECISION LOWERC,UPPERC,C,LOWERH,UPPERH,H,ANS,
     *TMP,ANSLO,ANSHI 
      INTEGER T,Q,N,CHOICE1,NTMP,I190,I260
      CHARACTER CHOICE2
      EXTERNAL ZCDF,PCSNGS,FACTOR
C
C   READ IN PARAMETERS FIXED FOR THE RUN: T,Q,SIGMA AND P-STAR
C
100   WRITE(6,*) 'ENTER T,Q,SIGMA AND P-STAR'
      READ(5,*) T,Q,SIGMA,PSTAR
      IF(Q .GE. T) THEN
      WRITE(6,*) 'Q MUST BE STRICTLY LESS THAN T, TRY AGAIN '
      GOTO 100
      ENDIF
C
110   WRITE(6,510)
120   WRITE(6,*) 'ENTER CHOICE (1, 2, OR 3) '
      READ(5,*) CHOICE1
      IF(CHOICE1 .EQ. 1) GOTO 130
      IF(CHOICE1 .EQ. 2) GOTO 140
      IF(CHOICE1 .EQ. 3) GOTO 150
      WRITE(6,*) 'ENTRY ERROR, TRY AGAIN '
      GOTO 120
130   WRITE(6,*) 'ENTER N AND H' 
      READ(5,*) N,H
      GOTO 160
140   WRITE(6,*) 'ENTER DELTA-STAR AND H'
      READ(5,*) DSTAR,H
160   TMP=1.0D0
      NTMP=1
      C = 4.0D0
      LOWERC = 0.0D0
C
C     DETERMINE UPPER AND LOWER VALUES AT WHICH TO START BISECTION
C
170   ANS = PCSNGS(T,Q,NTMP,C,TMP,H)
C
      IF(ANS .GT. PSTAR) GOTO 180
      C = C + 1
      GOTO 170
180   UPPERC = C
      C = (UPPERC + LOWERC)/2.0D0
C
C     PERFORM BINARY SEARCH WITH A MAXIMUM OF 50 ITERATIONS
C
      DO 190 I190 = 1,50
C
C     EVALUATE THE P{CS} AT A TRIAL DELTA-STAR
C
      ANS = PCSNGS(T,Q,NTMP,C,TMP,H)
C
      IF(DABS(ANS-PSTAR).LE.0.000001) GOTO 200
210   IF(ANS.GT.PSTAR) GOTO 220
      LOWERC = C
      C = (LOWERC + UPPERC)/2.
      GOTO 190
220   UPPERC = C
      C = (LOWERC + UPPERC)/2.
190   CONTINUE
C
200   IF(CHOICE1 .EQ. 1) GOTO 230
      N = DINT((SIGMA * C / DSTAR)**2) + 1 
      WRITE(6,520) T, Q, DSTAR, PSTAR, SIGMA, H, N
C
      WRITE(6,*) 'DO YOU WANT TO CONTINUE? PLEASE ANSWER Y/N'
      READ(5,500) CHOICE2
      IF (CHOICE2 .EQ. 'Y' .OR. CHOICE2 .EQ. 'y') GOTO 110
      STOP
C
230   DSTAR = C * SIGMA / DSQRT(DFLOAT(N)) 
      WRITE(6,530) T, Q, PSTAR, SIGMA, H, N, DSTAR 
C
      WRITE(6,*) 'DO YOU WANT TO CONTINUE? PLEASE ANSWER Y/N'
      READ(5,500) CHOICE2
      IF (CHOICE2 .EQ. 'Y' .OR. CHOICE2 .EQ. 'y') GOTO 110
      STOP
C
150   WRITE(6,*) 'ENTER DELTA-STAR AND N'
      READ(5,*) DSTAR,N
      H = 0.0D0
      ANSLO =  PCSNGS(T,Q,N,DSTAR,SIGMA,H)
      H = 1000.0D0
      ANSHI =  PCSNGS(T,Q,N,DSTAR,SIGMA,H)
      IF ((PSTAR .LE. ANSLO) .OR. (PSTAR .GE. ANSHI)) GOTO 290
      H = 0.0D0
      LOWERH = 0.0D0
240   ANS = PCSNGS(T,Q,N,DSTAR,SIGMA,H)
C
      IF(ANS .GT. PSTAR) GOTO 250
      H = H + 1
      GOTO 240
250   UPPERH = H
      H = (UPPERH + LOWERH)/2.0D0
C
C     PERFORM BINARY SEARCH WITH A MAXIMUM OF 50 ITERATIONS
C
      DO 260 I260 = 1,50
C
C     EVALUATE THE P{CS} AT A TRIAL H
C
      ANS = PCSNGS(T,Q,N,DSTAR,SIGMA,H)
C
      IF(DABS(ANS-PSTAR).LE.0.000001) GOTO 270
      IF(ANS.GT.PSTAR) GOTO 280
      LOWERH = H
      H = (LOWERH + UPPERH)/2.
      GOTO 260
280   UPPERH = H
      H = (LOWERH + UPPERH)/2.
260   CONTINUE
270   WRITE(6,540) T,Q,SIGMA,N,DSTAR,H
C
      WRITE(6,*) 'DO YOU WANT TO CONTINUE? PLEASE ANSWER Y/N'
      READ(5,500) CHOICE2
      IF (CHOICE2 .EQ. 'Y' .OR. CHOICE2 .EQ. 'y') GOTO 110
      STOP
290   WRITE(6,550) ANSLO, ANSHI,PSTAR
      GOTO 150
C
500   FORMAT(A1)
510   FORMAT(1X,'           CHOICE          GIVEN               FIND'/
     1'             1              N, H             DELTA-STAR'/
     2'             2            DELTA-STAR, H         N'/,
     3'             3            DELTA-STAR, N         H')
520   FORMAT(1X,' FOR (T, Q, DELTA*, P*, SIGMA, H) = ( ', I3, ',',
     *I3, ',',F5.3, ', ',F5.3, ', ',F5.3, ', ',F5.3,')' /
     *'  THE REQUIRED SAMPLE SIZE IS ', I6/)
530   FORMAT(1X,' FOR (T, Q, P*, SIGMA, H, N) = ( ', I3,',',I3,
     *',',F5.3, ', ',F5.3, ', ',F5.3,', ', I4,')' / '  THE ' 
     *'MINIMUM DELTA STAR WHICH CAN BE DETECTED WHILE' / '  ACHIEVING'
     *' (3.4.6) IS ', F7.3/)
540   FORMAT(1X,' FOR (T, Q, SIGMA, N, DELTA*) = ( ', I4,', ',
     * I4,', ',F5.3,', ', I5,', ',F7.3,')' / '  THE CRITICAL VALUE H
     * IS ', F6.3/) 
550   FORMAT(1X,'ONLY P-STAR BETWEEN 'F7.3,' AND ',F7.3,
     1' HAVE  H  VALUES IN [0,\INFTY)'/,1X,'THAT ACHIEVE P-STAR---',
     2'YOUR P-STAR = ',F7.3,'.  MODIFY DSTAR AND/OR N'/)
      END

