      PROGRAM USENB 
C
C     INTERACTIVE CALCULATION OF N, P-STAR OR DELTA-STAR FOR THE
C     SINGLE-STAGE PROCEDURE N_B TO ACHIEVE PROB REQUIREMENT (2.1.1)
C
C  INPUT: PROGRAM INTERACTIVELY ASKS FOR
C       T          = NUMBER OF TREATMENTS  (T .LEQ. 50-RESET BY MAXT) 
C       SIGMA      = STANDARD DEVIATION OF THE MEASURE ERROR
C  THEN PROMPTS FOR 1 OF 3 CHOICES FROM THE MENU
C
C           CHOICE             GIVEN               FIND
C             1              N, P-STAR          DELTA-STAR
C             2          DELTA-STAR, P-STAR         N
C             3            N, DELTA-STAR          P-STAR
C  WHERE 
C       DELTA-STAR = DIFFERENCE TO BE DETECTED 
C       P-STAR     = MINIMUM P{CS} OVER THE INDIFFERENCE-ZONE 
C       N          = SMALLEST COMMON NUMBER OF OBSERVATIONS PER 
C                    TREATMENT TO ATTAIN PROB REQUIREMENT (2.1.1)
C
C  OUTPUT: DELTA-STAR, N OR P-STAR
C
      INTEGER MAXT
C     MAXT = THE MAXIMUM NUMBER OF TREATMENTS
      PARAMETER (MAXT=50)
      DOUBLE PRECISION ZCDF,PCSNB
      DOUBLE PRECISION PSTAR,DSTAR,SIGMA,H 
      DOUBLE PRECISION ANS,TMP,LOWERH,UPPERH
      INTEGER T,N,CHOICE1,NTMP(MAXT),I190
      CHARACTER CHOICE2
      EXTERNAL ZCDF,PCSNB
C
C     READ T AND SIGMA 
      WRITE(6,*) 'ENTER T AND SIGMA'
      READ(5,*) T, SIGMA
C
100   WRITE(6,510)
110   WRITE(6,*) 'ENTER CHOICE (1, 2, OR 3) '
      READ(5,*) CHOICE1
      IF(CHOICE1 .EQ. 1) GOTO 120
      IF(CHOICE1 .EQ. 2) GOTO 130
      IF(CHOICE1 .EQ. 3) GOTO 140
      WRITE(6,*) 'ENTRY ERROR, TRY AGAIN '
      GOTO 110
120   WRITE(6,*) 'ENTER N AND P-STAR' 
      READ(5,*) N, PSTAR
      GOTO 150
130   WRITE(6,*) 'ENTER DELTA-STAR AND P-STAR'
      READ(5,*) DSTAR, PSTAR
C
C     COMPUTES Z^{1-PSTAR}_{T-1,1/2} USING A BINARY SEARCH  
C
150   DO 160 I = 1,T
160   NTMP(I) = 1
C
C     DETERMINE UPPER AND LOWER VALUES AT WHICH TO START BISECTION
C
      H = 0.0D0
      LOWERH = 0.0D0
      TMP=1.0D0
170   ANS = PCSNB(T,NTMP,H,TMP)
C
      IF(ANS .GT. PSTAR) GOTO 180
      H = H + 1.0D0
      GOTO 170
180   UPPERH = H
      H = (UPPERH + LOWERH)/2.0D0
C
C     PERFORM BINARY SEARCH WITH A MAXIMUM OF 50 ITERATIONS
C
      DO 190 I190 = 1,50
      ANS = PCSNB(T,NTMP,H,TMP)
      IF(DABS(ANS-PSTAR).LE.0.000001) GOTO 200
      IF(ANS.GT.PSTAR) GOTO 210
      LOWERH = H
      H = (LOWERH + UPPERH)/2.
      GOTO 190
210   UPPERH = H
      H = (LOWERH + UPPERH)/2.
190   CONTINUE
C
200   IF(CHOICE1 .EQ. 1) GOTO 220
      N = DINT((SIGMA * H / DSTAR)**2) + 1 
      WRITE(6,520) T, DSTAR, PSTAR, SIGMA, N
C
      WRITE(6,*) 'DO YOU WANT TO CONTINUE? PLEASE ANSWER Y/N'
      READ(5,500) CHOICE2
      IF (CHOICE2 .EQ. 'Y' .OR. CHOICE2 .EQ. 'y') GOTO 100
      STOP
C
220   DSTAR = H * SIGMA / DSQRT(DFLOAT(N)) 
      WRITE(6,530) T, PSTAR, SIGMA, N, DSTAR 
C
      WRITE(6,*) 'DO YOU WANT TO CONTINUE? PLEASE ANSWER Y/N'
      READ(5,500) CHOICE2
      IF (CHOICE2 .EQ. 'Y' .OR. CHOICE2 .EQ. 'y') GOTO 100
      STOP
C
C     CHOICE1 = 3 BRANCH
C
140   WRITE(6,*) 'ENTER N AND DELTA-STAR' 
      READ(5,*) N, DSTAR
      DO 230 I =1,T
      NTMP(I) = N
230   CONTINUE
      ANS = PCSNB(T,NTMP,DSTAR,SIGMA)
      WRITE(6,540) T,SIGMA,N,DSTAR,ANS
C
      WRITE(6,*) 'DO YOU WANT TO CONTINUE? PLEASE ANSWER Y/N'
      READ(5,500) CHOICE2
      IF (CHOICE2 .EQ. 'Y' .OR. CHOICE2 .EQ. 'y') GOTO 100
C
500   FORMAT(A1)
510   FORMAT(1X,'           CHOICE          GIVEN               FIND'/
     *'             1            N, P-STAR          DELTA-STAR'/
     *'             2          DELTA-STAR, P-STAR      N'/,
     *'             3            N, DELTA-STAR        P-STAR')
520   FORMAT(1X,'FOR (T, DELTA*, P*, SIGMA) = ( ', I4,', ', 
     * F5.2, ', ',F5.3, ', ',F5.2,')' /1X, 'THE REQUIRED '
     *'SAMPLE SIZE FOR BECHHOFER PROCEDURE B_1 IS N = ', I6/)
530     FORMAT(1X,'FOR (T, P*, SIGMA,N) = ( ', I4, ', ',
     *F5.2, ', ',F5.3, ', ', I5,')' / ' THE MINIMUM ',
     *'DELTA STAR WHICH CAN BE DETECTED WHILE' / ' ACHIEVING (2.2) '
     *'IS DELTA-STAR = ', F7.3/)
540     FORMAT(1X,'FOR (T, SIGMA,N,DELTA*) = ( ', I4,', ',
     *F5.2,', ', I5,', ',F7.3,')' / ' THE ACHIEVED P-STAR IN ' 
     *'(2.2) IS P-STAR = ', F5.3/) 
      STOP
      END




